@@ -6,7 +6,7 @@ use Capture::Tiny qw/:all/;
 use Types::Path::Tiny qw/Path/;
 use String::ShellQuote;
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 =head1 NAME
 
@@ -95,13 +95,12 @@ sub local {
 
 =over 4
 
+=item Shell::Cmd
+
 =item Capture::Tiny::Extended
 
 =item Net::OpenSSH
 
-Net::OpenSSH has better performance because it uses a single ssh connection for
-the life of the object.  Its a mature project with lots of functionality.  
-
 =item Capture::Tiny
 
 =item IPC::System::Simple
@@ -121,8 +120,5 @@ it under the same terms as Perl itself.
 
 Eric Johnson E<lt>eric.git@iijo.orgE<gt>
 
-But most of the code is heavily borrowed from Miyagawa's excellent
-App::cpanminus module.
-
 =cut
 
